# TraitGPT


[![pypi](https://img.shields.io/pypi/v/traitgpt.svg)](https://pypi.org/project/traitgpt/)
[![python](https://img.shields.io/pypi/pyversions/traitgpt.svg)](https://pypi.org/project/traitgpt/)
[![Build Status](https://github.com/Jianhua-Wang/traitgpt/actions/workflows/dev.yml/badge.svg)](https://github.com/Jianhua-Wang/traitgpt/actions/workflows/dev.yml)
[![codecov](https://codecov.io/gh/Jianhua-Wang/traitgpt/branch/main/graphs/badge.svg)](https://codecov.io/github/Jianhua-Wang/traitgpt)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)



Mapping trait to ontology using GPT


* Documentation: <https://Jianhua-Wang.github.io/TraitGPT>
* GitHub: <https://github.com/Jianhua-Wang/traitgpt>
* PyPI: <https://pypi.org/project/traitgpt/>
* Free software: MIT


## Features

* TODO

## Credits

This package was created with [Cookiecutter](https://github.com/audreyr/cookiecutter) and the [waynerv/cookiecutter-pypackage](https://github.com/waynerv/cookiecutter-pypackage) project template.
